==> loadmychunks-1.2.0%2B1.20.1%2Bfabric-sources.jar: com/drathonix/loadmychunks/common/mixin/cct/MixinTileTurtle.java <==
package com.drathonix.loadmychunks.common.mixin.cct;

//? if !computercraft {
/*import com.drathonix.loadmychunks.common.LoadMyChunks;
import org.spongepowered.asm.mixin.Mixin;
@Mixin(LoadMyChunks.class)
public class MixinTileTurtle {

}
*///?}
//? if computercraft {

import com.drathonix.loadmychunks.common.bridge.IContextDestroyable;
import com.drathonix.loadmychunks.common.bridge.IDestroyable;
import com.drathonix.loadmychunks.common.integ.cct.bridge.ITurtleBrainMixin;
import com.drathonix.loadmychunks.common.integ.cct.turtle.TurtleChunkLoader;
import com.drathonix.loadmychunks.common.system.ChunkDataManager;
import com.drathonix.loadmychunks.common.system.ChunkDataModule;
import com.drathonix.loadmychunks.common.system.loaders.IChunkLoader;
import com.drathonix.loadmychunks.common.system.loaders.IHasChunkloader;
import com.drathonix.loadmychunks.common.util.MultiversioningHelper;
import dan200.computercraft.api.peripheral.IPeripheral;
import dan200.computercraft.api.turtle.TurtleSide;
//? if >1.19.2
import dan200.computercraft.shared.turtle.blocks.TurtleBlockEntity;
//? if <=1.19.2
/*import dan200.computercraft.shared.turtle.blocks.TileTurtle;*/
import dan200.computercraft.shared.turtle.core.TurtleBrain;
import net.minecraft.class_2338;
import net.minecraft.class_2586;
import org.jetbrains.annotations.Nullable;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.Shadow;
import org.spongepowered.asm.mixin.injection.Inject;

//? if >1.19.2
@Mixin(value = TurtleBlockEntity.class,remap = false)
//? if <=1.19.2
/*@Mixin(value = TileTurtle.class,remap = false)*/
public abstract class MixinTileTurtle implements IDestroyable,IHasChunkloader {
    @Shadow
    private TurtleBrain brain;

    @Override
    public void loadMyChunks$destroy() {
        MultiversioningHelper.serverLevel((class_2586)(Object)this, sl-> {
            class_2338 pos = ((class_2586)(Object)this).method_11016();
            TurtleChunkLoader query = ((ITurtleBrainMixin)brain).lmc$getChunkLoader().move(pos);
            ChunkDataManager.removeChunkLoader(sl,pos,query);
        });
    }

    @Override
    public @Nullable IChunkLoader loadMyChunks$getChunkLoader() {
        MultiversioningHelper.serverLevel(((class_2586)(Object)this),sl->{
            class_2338 pos = ((class_2586)(Object)this).method_11016();
            return ChunkDataManager.getOrCreateChunkData(sl, pos).getChunkLoaderAt(pos);
        });
        return null;
    }
}
//?}

==> loadmychunks-1.2.1%2B1.20.6%2Bfabric-sources.jar: com/drathonix/loadmychunks/common/mixin/cct/MixinTileTurtle.java <==
package com.drathonix.loadmychunks.common.mixin.cct;

//? if !computercraft {
/*import com.drathonix.loadmychunks.common.LoadMyChunks;
import org.spongepowered.asm.mixin.Mixin;
@Mixin(LoadMyChunks.class)
public class MixinTileTurtle {

}
*///?}
//? if computercraft {

import com.drathonix.loadmychunks.common.bridge.IContextDestroyable;
import com.drathonix.loadmychunks.common.bridge.IDestroyable;
import com.drathonix.loadmychunks.common.integ.cct.bridge.ITileTurtleMixin;
import com.drathonix.loadmychunks.common.integ.cct.bridge.ITurtleBrainMixin;
import com.drathonix.loadmychunks.common.integ.cct.turtle.TurtleChunkLoader;
import com.drathonix.loadmychunks.common.system.ChunkDataManager;
import com.drathonix.loadmychunks.common.system.ChunkDataModule;
import com.drathonix.loadmychunks.common.system.loaders.IChunkLoader;
import com.drathonix.loadmychunks.common.system.loaders.IHasChunkloader;
import com.drathonix.loadmychunks.common.util.MultiversioningHelper;
import dan200.computercraft.api.peripheral.IPeripheral;
import dan200.computercraft.api.turtle.TurtleSide;
//? if >1.19.2
import dan200.computercraft.shared.turtle.blocks.TurtleBlockEntity;
//? if <=1.19.2
/*import dan200.computercraft.shared.turtle.blocks.TileTurtle;*/
import dan200.computercraft.shared.turtle.core.TurtleBrain;
import net.minecraft.class_2338;
import net.minecraft.class_2586;
import org.jetbrains.annotations.Nullable;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.Shadow;
import org.spongepowered.asm.mixin.injection.Inject;

//? if >1.19.2
@Mixin(value = TurtleBlockEntity.class,remap = false)
//? if <=1.19.2
/*@Mixin(value = TileTurtle.class,remap = false)*/
public abstract class MixinTileTurtle implements IDestroyable,IHasChunkloader, ITileTurtleMixin {
    @Shadow
    private TurtleBrain brain;

    @Override
    public ITurtleBrainMixin loadMyChunks$getBrain() {
        return (ITurtleBrainMixin)brain;
    }

    @Override
    public void loadMyChunks$destroy() {
        MultiversioningHelper.serverLevel((class_2586)(Object)this, sl-> {
            class_2338 pos = ((class_2586)(Object)this).method_11016();
            TurtleChunkLoader query = ((ITurtleBrainMixin)brain).lmc$getChunkLoader().move(pos);
            ChunkDataManager.removeChunkLoader(sl,pos,query);
        });
    }

    @Override
    public @Nullable IChunkLoader loadMyChunks$getChunkLoader() {
        MultiversioningHelper.serverLevel(((class_2586)(Object)this),sl->{
            class_2338 pos = ((class_2586)(Object)this).method_11016();
            return ChunkDataManager.getOrCreateChunkData(sl, pos).getChunkLoaderAt(pos);
        });
        return null;
    }
}
//?}
